@@ -1,7 +1,7 @@
 """Ensemble backend that combines results from multiple projects"""
 
 
-import annif.hit
+import annif.suggestion
 import annif.project
 import annif.util
 from . import backend
@@ -16,24 +16,30 @@ class EnsembleBackend(backend.AnnifBackend):
         by subclasses."""
         return hits
 
-    def _analyze_with_sources(self, text, sources):
+    def _suggest_with_sources(self, text, sources):
         hits_from_sources = []
         for project_id, weight in sources:
             source_project = annif.project.get_project(project_id)
-            hits = source_project.analyze(text)
+            hits = source_project.suggest(text)
             self.debug(
                 'Got {} hits from project {}'.format(
                     len(hits), source_project.project_id))
             norm_hits = self._normalize_hits(hits, source_project)
             hits_from_sources.append(
-                annif.hit.WeightedHits(
+                annif.suggestion.WeightedSuggestion(
                     hits=norm_hits, weight=weight))
         return hits_from_sources
 
-    def _analyze(self, text, project, params):
+    def _merge_hits_from_sources(self, hits_from_sources, project, params):
+        """Hook for merging hits from sources. Can be overridden by
+        subclasses."""
+        return annif.util.merge_hits(hits_from_sources, project.subjects)
+
+    def _suggest(self, text, project, params):
         sources = annif.util.parse_sources(params['sources'])
-        hits_from_sources = self._analyze_with_sources(text, sources)
-        merged_hits = annif.util.merge_hits(
-            hits_from_sources, project.subjects)
+        hits_from_sources = self._suggest_with_sources(text, sources)
+        merged_hits = self._merge_hits_from_sources(hits_from_sources,
+                                                    project,
+                                                    params)
         self.debug('{} hits after merging'.format(len(merged_hits)))
         return merged_hits
