@@ -5,7 +5,7 @@ import os.path
 import gensim.similarities
 from gensim.matutils import Sparse2Corpus
 import annif.util
-from annif.hit import VectorAnalysisResult
+from annif.suggestion import VectorSuggestionResult
 from annif.exception import NotInitializedException
 from . import backend
 
@@ -45,11 +45,10 @@ class TFIDFBackend(backend.AnnifBackend):
             self.datadir,
             self.INDEX_FILE)
 
-    def _analyze(self, text, project, params):
-        self.initialize()
-        self.debug('Analyzing text "{}..." (len={})'.format(
+    def _suggest(self, text, project, params):
+        self.debug('Suggesting subjects for text "{}..." (len={})'.format(
             text[:20], len(text)))
         vectors = project.vectorizer.transform([text])
         docsim = self._index[vectors[0]]
-        fullresult = VectorAnalysisResult(docsim, project.subjects)
+        fullresult = VectorSuggestionResult(docsim, project.subjects)
         return fullresult.filter(limit=int(self.params['limit']))
