@@ -7,3 +7,7 @@ from .subject import SubjectIndex, SubjectSet
 from .skos import SubjectFileSKOS
 from .types import Document
 from .combine import CombinedCorpus
+
+__all__ = [DocumentDirectory, DocumentFile, DocumentList, Subject,
+           SubjectDirectory, SubjectFileTSV, SubjectIndex, SubjectSet,
+           SubjectFileSKOS, Document, CombinedCorpus]
