@@ -19,7 +19,7 @@ class SubjectDirectory(SubjectCorpus, SubjectToDocumentCorpusMixin):
     @property
     def subjects(self):
         for filename in self._filenames:
-            with open(filename) as subjfile:
+            with open(filename, encoding='utf-8') as subjfile:
                 uri, label = subjfile.readline().strip().split(' ', 1)
                 text = ' '.join(subjfile.readlines())
                 yield Subject(uri=uri, label=label, text=text)
@@ -33,7 +33,7 @@ class SubjectFileTSV(SubjectCorpus, SubjectToDocumentCorpusMixin):
 
     @property
     def subjects(self):
-        with open(self.path) as subjfile:
+        with open(self.path, encoding='utf-8') as subjfile:
             for line in subjfile:
                 uri, label = line.strip().split(None, 1)
                 clean_uri = annif.util.cleanup_uri(uri)
@@ -78,10 +78,26 @@ class SubjectIndex:
             logger.warning('Unknown subject label "%s"', label)
             return None
 
+    def uris_to_labels(self, uris):
+        """return a list of labels corresponding to the given URIs; unknown
+        URIs are ignored"""
+
+        return [self[subject_id][1]
+                for subject_id in (self.by_uri(uri) for uri in uris)
+                if subject_id is not None]
+
+    def labels_to_uris(self, labels):
+        """return a list of URIs corresponding to the given labels; unknown
+        labels are ignored"""
+
+        return [self[subject_id][0]
+                for subject_id in (self.by_label(label) for label in labels)
+                if subject_id is not None]
+
     def save(self, path):
         """Save this subject index into a file."""
 
-        with open(path, 'w') as subjfile:
+        with open(path, 'w', encoding='utf-8') as subjfile:
             for subject_id in range(len(self)):
                 line = "<{}>\t{}".format(
                     self._uris[subject_id], self._labels[subject_id])
