@@ -4,7 +4,7 @@ methods defined in the Swagger specification."""
 import connexion
 import annif.project
 from annif.corpus import Document, DocumentList
-from annif.hit import HitFilter
+from annif.suggestion import SuggestionFilter
 from annif.exception import AnnifException
 from annif.project import Access
 
@@ -48,9 +48,9 @@ def show_project(project_id):
     return project.dump()
 
 
-def analyze(project_id, text, limit, threshold):
-    """analyze text and return a dict with results formatted according to
-    Swagger spec"""
+def suggest(project_id, text, limit, threshold):
+    """suggest subjects for the given text and return a dict with results
+    formatted according to Swagger spec"""
 
     try:
         project = annif.project.get_project(
@@ -58,9 +58,9 @@ def analyze(project_id, text, limit, threshold):
     except ValueError:
         return project_not_found_error(project_id)
 
-    hit_filter = HitFilter(limit, threshold)
+    hit_filter = SuggestionFilter(limit, threshold)
     try:
-        result = project.analyze(text)
+        result = project.suggest(text)
     except AnnifException as err:
         return server_error(err)
     hits = hit_filter(result)
