@@ -1,6 +1,5 @@
 """Unit tests for backends in Annif"""
 
-import os
 import pytest
 import annif
 import annif.backend
@@ -16,7 +15,7 @@ def test_get_backend_dummy(app, project):
     dummy_type = annif.backend.get_backend("dummy")
     dummy = dummy_type(backend_id='dummy', params={},
                        datadir=app.config['DATADIR'])
-    result = dummy.analyze(text='this is some text', project=project)
+    result = dummy.suggest(text='this is some text', project=project)
     assert len(result) == 1
     assert result[0].uri == 'http://example.org/dummy'
     assert result[0].label == 'dummy'
@@ -36,7 +35,7 @@ def test_learn_dummy(app, project, tmpdir):
 
     dummy.learn(docdir, project)
 
-    result = dummy.analyze(text='this is some text', project=project)
+    result = dummy.suggest(text='this is some text', project=project)
     assert len(result) == 1
     assert result[0].uri == 'http://example.org/key1'
     assert result[0].label == 'key1'
