@@ -4,8 +4,6 @@ import contextlib
 import random
 import re
 import os.path
-import shutil
-import pytest
 from click.testing import CliRunner
 import annif.cli
 
@@ -14,6 +12,7 @@ runner = CliRunner(env={'ANNIF_CONFIG': 'annif.default_config.TestingConfig'})
 # Generate a random project name to use in tests
 TEMP_PROJECT = ''.join(
     random.choice('abcdefghiklmnopqrstuvwxyz') for _ in range(8))
+PROJECTS_FILE_OPTION = 'tests/projects_for_config_path_option.cfg'
 
 
 def test_list_projects():
@@ -40,6 +39,26 @@ def test_list_projects_bad_arguments():
         annif.cli.run_list_projects, ['moi', '--debug', 'y']).exit_code != 0
 
 
+def test_list_projects_config_path_option():
+    result = runner.invoke(
+        annif.cli.cli, ["list-projects", "--projects", PROJECTS_FILE_OPTION])
+    assert not result.exception
+    assert result.exit_code == 0
+    assert 'dummy_for_projects_option' in result.output
+    assert 'dummy-fi' not in result.output
+    assert 'dummy-en' not in result.output
+
+
+def test_list_projects_config_path_option_nonexistent():
+    nonexistent_file = "nonexistent.cfg"
+    result = runner.invoke(
+        annif.cli.cli, ["list-projects", "--projects", nonexistent_file])
+    assert not result.exception
+    assert result.exit_code == 0
+    assert 'Project configuration file "{}" is missing.'.format(
+        nonexistent_file) in result.output
+
+
 def test_show_project():
     result = runner.invoke(annif.cli.cli, ['show-project', 'dummy-en'])
     assert not result.exception
@@ -65,6 +84,29 @@ def test_show_project_nonexistent():
     assert failed_result.exception
 
 
+def test_clear_project(testdatadir):
+    dirpath = os.path.join(str(testdatadir), 'projects', 'dummy-fi')
+    fpath = os.path.join(str(dirpath), 'test_clear_project_datafile')
+    os.makedirs(dirpath)
+    open(fpath, 'a').close()
+
+    assert runner.invoke(
+        annif.cli.cli,
+        ['clear', 'dummy-fi']).exit_code == 0
+    assert not os.path.isdir(dirpath)
+
+
+def test_clear_project_nonexistent_data(testdatadir, caplog):
+    logger = annif.logger
+    logger.propagate = True
+    runner.invoke(
+        annif.cli.cli,
+        ['clear', 'dummy-fi']).exit_code != 0
+    assert len(caplog.records) == 1
+    expected_msg = 'No model data to remove for project dummy-fi.'
+    assert expected_msg == caplog.records[0].message
+
+
 def test_loadvoc_tsv(testdatadir):
     with contextlib.suppress(FileNotFoundError):
         os.remove(str(testdatadir.join('projects/tfidf-fi/subjects')))
@@ -148,20 +190,20 @@ def test_learn_notsupported(testdatadir):
     assert 'Learning not supported' in result.output
 
 
-def test_analyze():
+def test_suggest():
     result = runner.invoke(
         annif.cli.cli,
-        ['analyze', 'dummy-fi'],
+        ['suggest', 'dummy-fi'],
         input='kissa')
     assert not result.exception
     assert result.output == "<http://example.org/dummy>\tdummy\t1.0\n"
     assert result.exit_code == 0
 
 
-def test_analyze_nonexistent():
+def test_suggest_nonexistent():
     result = runner.invoke(
         annif.cli.cli,
-        ['analyze', TEMP_PROJECT],
+        ['suggest', TEMP_PROJECT],
         input='kissa')
     assert result.exception
     assert result.output == "No projects found with id '{}'.\n".format(
@@ -169,31 +211,31 @@ def test_analyze_nonexistent():
     assert result.exit_code != 0
 
 
-def test_analyze_param():
+def test_suggest_param():
     result = runner.invoke(
         annif.cli.cli,
-        ['analyze', '--backend-param', 'dummy.score=0.8', 'dummy-fi'],
+        ['suggest', '--backend-param', 'dummy.score=0.8', 'dummy-fi'],
         input='kissa')
     assert not result.exception
     assert result.output == "<http://example.org/dummy>\tdummy\t0.8\n"
     assert result.exit_code == 0
 
 
-def test_analyze_ensemble():
+def test_suggest_ensemble():
     result = runner.invoke(
         annif.cli.cli,
-        ['analyze', 'ensemble'],
+        ['suggest', 'ensemble'],
         input='the cat sat on the mat')
     assert not result.exception
     assert result.output == "<http://example.org/dummy>\tdummy\t1.0\n"
     assert result.exit_code == 0
 
 
-def test_analyzedir(tmpdir):
+def test_index(tmpdir):
     tmpdir.join('doc1.txt').write('nothing special')
 
     result = runner.invoke(
-        annif.cli.cli, ['analyzedir', 'dummy-en', str(tmpdir)])
+        annif.cli.cli, ['index', 'dummy-en', str(tmpdir)])
     assert not result.exception
     assert result.exit_code == 0
 
@@ -203,14 +245,14 @@ def test_analyzedir(tmpdir):
 
     # make sure that preexisting subject files are not overwritten
     result = runner.invoke(
-        annif.cli.cli, ['analyzedir', 'dummy-en', str(tmpdir)])
+        annif.cli.cli, ['index', 'dummy-en', str(tmpdir)])
     assert not result.exception
     assert result.exit_code == 0
     assert "Not overwriting" in result.output
 
     # check that the --force parameter forces overwriting
     result = runner.invoke(
-        annif.cli.cli, ['analyzedir', 'dummy-fi', '--force', str(tmpdir)])
+        annif.cli.cli, ['index', 'dummy-fi', '--force', str(tmpdir)])
     assert tmpdir.join('doc1.annif').exists()
     assert "Not overwriting" not in result.output
     assert tmpdir.join('doc1.annif').read_text(
