@@ -115,11 +115,11 @@ def test_docdir_tsv_require_subjects(tmpdir):
     assert files[1][1] == str(tmpdir.join('doc2.tsv'))
 
 
-def test_docdir_as_doccorpus(tmpdir):
+def test_docdir_tsv_as_doccorpus(tmpdir):
     tmpdir.join('doc1.txt').write('doc1')
     tmpdir.join('doc1.tsv').write('<http://example.org/subj1>\tsubj1')
     tmpdir.join('doc2.txt').write('doc2')
-    tmpdir.join('doc2.tsv').write('<http://example.org/subj2>\tsubj1')
+    tmpdir.join('doc2.tsv').write('<http://example.org/subj2>\tsubj2')
     tmpdir.join('doc3.txt').write('doc3')
 
     docdir = annif.corpus.DocumentDirectory(str(tmpdir), require_subjects=True)
@@ -131,6 +131,23 @@ def test_docdir_as_doccorpus(tmpdir):
     assert docs[1].uris == {'http://example.org/subj2'}
 
 
+def test_docdir_key_as_doccorpus(tmpdir, subject_index):
+    tmpdir.join('doc1.txt').write('doc1')
+    tmpdir.join('doc1.key').write('arkeologit')
+    tmpdir.join('doc2.txt').write('doc2')
+    tmpdir.join('doc2.key').write('kalliotaide')
+    tmpdir.join('doc3.txt').write('doc3')
+
+    docdir = annif.corpus.DocumentDirectory(str(tmpdir), require_subjects=True)
+    docdir.set_subject_index(subject_index)
+    docs = list(docdir.documents)
+    assert len(docs) == 2
+    assert docs[0].text == 'doc1'
+    assert docs[0].uris == {'http://www.yso.fi/onto/yso/p10849'}
+    assert docs[1].text == 'doc2'
+    assert docs[1].uris == {'http://www.yso.fi/onto/yso/p13027'}
+
+
 def test_subjdir(tmpdir):
     tmpdir.join('subj1.txt').write("""http://example.org/subj1 subject one
         first subject
@@ -201,6 +218,23 @@ def test_docfile_plain(tmpdir):
     assert len(list(docs.documents)) == 3
 
 
+def test_docfile_plain_invalid_lines(tmpdir, caplog):
+    logger = annif.logger
+    logger.propagate = True
+    docfile = tmpdir.join('documents_invalid.tsv')
+    docfile.write("""Läntinen\t<http://www.yso.fi/onto/yso/p2557>
+
+        Oulunlinnan\t<http://www.yso.fi/onto/yso/p7346>
+        A line with no tabs
+        Harald Hirmuinen\t<http://www.yso.fi/onto/yso/p6479>""")
+    docs = annif.corpus.DocumentFile(str(docfile))
+    assert len(list(docs.documents)) == 3
+    assert len(caplog.records) == 2
+    expected_msg = 'Skipping invalid line (missing tab):'
+    for record in caplog.records:
+        assert expected_msg in record.message
+
+
 def test_docfile_gzipped(tmpdir):
     docfile = tmpdir.join('documents.tsv.gz')
     with gzip.open(str(docfile), 'wt') as gzf:
